<picture>
  <source media="(prefers-color-scheme: dark)" srcset="https://github.com/mjyb16/supermage/blob/main/SuperMAGE_logo_text.svg" width="70%" height="70%">
  <source media="(prefers-color-scheme: light)" srcset="https://github.com/mjyb16/supermage/blob/main/SuperMAGE_logo_text.svg" width="70%" height="70%">
  <img alt="SuperMAGE logo" src="https://github.com/mjyb16/supermage/blob/main/SuperMAGE_logo_text.svg" width="70%">
</picture>

# supermage
SuperMAGE: **Super**b **ma**sses from **g**as kin**e**matics

While gas dynamical supermassive black hole mass measurement is SuperMAGE's primary use case (and the original meaning of Super in its name), as a modular simulator, you can use any of its modules for any purpose. Broadly speaking, if you work with spectral cubes and/or rotation curves in galaxies, you might find SuperMAGE useful for your work. SuperMAGE is designed to interface with the gravitational lensing software Caustics, so you can use it to model lensed galaxies as well.

NOTE: Active development. Non-functioning and untested code may occur. For notebooks, see other repo.
